=============
Release Notes
=============

Version 0.2.1, 2015-10-27
=========================

- Fix unit tests due to changes in Pandas

Version 0.2, 2014-12-23
=======================

- Update to PyScaffold 1.3.1
- Minor fixes in docs
- Added exercises and presentation
- Added plot_forecast function

Version 0.1, 2014-07-11
=======================

- First release
